==> mesa-10.6.4-i586-1.txz: install/doinst.sh <==
( cd usr/lib ; rm -rf libxatracker.so )
( cd usr/lib ; ln -sf libxatracker.so.2.2.0 libxatracker.so )
( cd usr/lib ; rm -rf libXvMCr600.so.1 )
( cd usr/lib ; ln -sf libXvMCr600.so.1.0.0 libXvMCr600.so.1 )
( cd usr/lib ; rm -rf libGL.so )
( cd usr/lib ; ln -sf libGL.so.1.2.0 libGL.so )
( cd usr/lib ; rm -rf libOSMesa.so.8 )
( cd usr/lib ; ln -sf libOSMesa.so.8.0.0 libOSMesa.so.8 )
( cd usr/lib ; rm -rf libEGL.so )
( cd usr/lib ; ln -sf libEGL.so.1.0.0 libEGL.so )
( cd usr/lib ; rm -rf libgbm.so.1 )
( cd usr/lib ; ln -sf libgbm.so.1.0.0 libgbm.so.1 )
( cd usr/lib ; rm -rf libGL.so.1 )
( cd usr/lib ; ln -sf libGL.so.1.2.0 libGL.so.1 )
( cd usr/lib ; rm -rf libXvMCnouveau.so.1 )
( cd usr/lib ; ln -sf libXvMCnouveau.so.1.0.0 libXvMCnouveau.so.1 )
( cd usr/lib ; rm -rf libXvMCnouveau.so.1.0 )
( cd usr/lib ; ln -sf libXvMCnouveau.so.1.0.0 libXvMCnouveau.so.1.0 )
( cd usr/lib ; rm -rf libGLESv1_CM.so )
( cd usr/lib ; ln -sf libGLESv1_CM.so.1.1.0 libGLESv1_CM.so )
( cd usr/lib ; rm -rf libxatracker.so.2 )
( cd usr/lib ; ln -sf libxatracker.so.2.2.0 libxatracker.so.2 )
( cd usr/lib ; rm -rf libXvMCnouveau.so )
( cd usr/lib ; ln -sf libXvMCnouveau.so.1.0.0 libXvMCnouveau.so )
( cd usr/lib ; rm -rf libXvMCr600.so.1.0 )
( cd usr/lib ; ln -sf libXvMCr600.so.1.0.0 libXvMCr600.so.1.0 )
( cd usr/lib ; rm -rf libglapi.so )
( cd usr/lib ; ln -sf libglapi.so.0.0.0 libglapi.so )
( cd usr/lib ; rm -rf libglapi.so.0 )
( cd usr/lib ; ln -sf libglapi.so.0.0.0 libglapi.so.0 )
( cd usr/lib ; rm -rf libEGL.so.1 )
( cd usr/lib ; ln -sf libEGL.so.1.0.0 libEGL.so.1 )
( cd usr/lib ; rm -rf libgbm.so )
( cd usr/lib ; ln -sf libgbm.so.1.0.0 libgbm.so )
( cd usr/lib/vdpau ; rm -rf libvdpau_radeonsi.so.1 )
( cd usr/lib/vdpau ; ln -sf libvdpau_radeonsi.so.1.0.0 libvdpau_radeonsi.so.1 )
( cd usr/lib/vdpau ; rm -rf libvdpau_r300.so.1.0 )
( cd usr/lib/vdpau ; ln -sf libvdpau_r300.so.1.0.0 libvdpau_r300.so.1.0 )
( cd usr/lib/vdpau ; rm -rf libvdpau_r300.so.1 )
( cd usr/lib/vdpau ; ln -sf libvdpau_r300.so.1.0.0 libvdpau_r300.so.1 )
( cd usr/lib/vdpau ; rm -rf libvdpau_r600.so.1 )
( cd usr/lib/vdpau ; ln -sf libvdpau_r600.so.1.0.0 libvdpau_r600.so.1 )
( cd usr/lib/vdpau ; rm -rf libvdpau_nouveau.so.1.0 )
( cd usr/lib/vdpau ; ln -sf libvdpau_nouveau.so.1.0.0 libvdpau_nouveau.so.1.0 )
( cd usr/lib/vdpau ; rm -rf libvdpau_nouveau.so )
( cd usr/lib/vdpau ; ln -sf libvdpau_nouveau.so.1.0.0 libvdpau_nouveau.so )
( cd usr/lib/vdpau ; rm -rf libvdpau_radeonsi.so.1.0 )
( cd usr/lib/vdpau ; ln -sf libvdpau_radeonsi.so.1.0.0 libvdpau_radeonsi.so.1.0 )
( cd usr/lib/vdpau ; rm -rf libvdpau_r600.so.1.0 )
( cd usr/lib/vdpau ; ln -sf libvdpau_r600.so.1.0.0 libvdpau_r600.so.1.0 )
( cd usr/lib/vdpau ; rm -rf libvdpau_r300.so )
( cd usr/lib/vdpau ; ln -sf libvdpau_r300.so.1.0.0 libvdpau_r300.so )
( cd usr/lib/vdpau ; rm -rf libvdpau_r600.so )
( cd usr/lib/vdpau ; ln -sf libvdpau_r600.so.1.0.0 libvdpau_r600.so )
( cd usr/lib/vdpau ; rm -rf libvdpau_nouveau.so.1 )
( cd usr/lib/vdpau ; ln -sf libvdpau_nouveau.so.1.0.0 libvdpau_nouveau.so.1 )
( cd usr/lib/vdpau ; rm -rf libvdpau_radeonsi.so )
( cd usr/lib/vdpau ; ln -sf libvdpau_radeonsi.so.1.0.0 libvdpau_radeonsi.so )
( cd usr/lib ; rm -rf libGLESv2.so )
( cd usr/lib ; ln -sf libGLESv2.so.2.0.0 libGLESv2.so )
( cd usr/lib ; rm -rf libOSMesa.so )
( cd usr/lib ; ln -sf libOSMesa.so.8.0.0 libOSMesa.so )
( cd usr/lib ; rm -rf libGLESv2.so.2 )
( cd usr/lib ; ln -sf libGLESv2.so.2.0.0 libGLESv2.so.2 )
( cd usr/lib ; rm -rf libGLESv1_CM.so.1 )
( cd usr/lib ; ln -sf libGLESv1_CM.so.1.1.0 libGLESv1_CM.so.1 )
( cd usr/lib ; rm -rf libXvMCr600.so )
( cd usr/lib ; ln -sf libXvMCr600.so.1.0.0 libXvMCr600.so )

==> mesa-11.2.2-i586-1.txz: install/doinst.sh <==
( cd usr/lib/d3d ; rm -rf d3dadapter9.so )
( cd usr/lib/d3d ; ln -sf d3dadapter9.so.1.0.0 d3dadapter9.so )
( cd usr/lib/d3d ; rm -rf d3dadapter9.so.1 )
( cd usr/lib/d3d ; ln -sf d3dadapter9.so.1.0.0 d3dadapter9.so.1 )
( cd usr/lib ; rm -rf libxatracker.so )
( cd usr/lib ; ln -sf libxatracker.so.2.3.0 libxatracker.so )
( cd usr/lib ; rm -rf libXvMCr600.so.1 )
( cd usr/lib ; ln -sf libXvMCr600.so.1.0.0 libXvMCr600.so.1 )
( cd usr/lib ; rm -rf libGL.so )
( cd usr/lib ; ln -sf libGL.so.1.2.0 libGL.so )
( cd usr/lib ; rm -rf libOSMesa.so.8 )
( cd usr/lib ; ln -sf libOSMesa.so.8.0.0 libOSMesa.so.8 )
( cd usr/lib ; rm -rf libEGL.so )
( cd usr/lib ; ln -sf libEGL.so.1.0.0 libEGL.so )
( cd usr/lib ; rm -rf libgbm.so.1 )
( cd usr/lib ; ln -sf libgbm.so.1.0.0 libgbm.so.1 )
( cd usr/lib ; rm -rf libGL.so.1 )
( cd usr/lib ; ln -sf libGL.so.1.2.0 libGL.so.1 )
( cd usr/lib ; rm -rf libXvMCnouveau.so.1 )
( cd usr/lib ; ln -sf libXvMCnouveau.so.1.0.0 libXvMCnouveau.so.1 )
( cd usr/lib ; rm -rf libXvMCnouveau.so.1.0 )
( cd usr/lib ; ln -sf libXvMCnouveau.so.1.0.0 libXvMCnouveau.so.1.0 )
( cd usr/lib ; rm -rf libGLESv1_CM.so )
( cd usr/lib ; ln -sf libGLESv1_CM.so.1.1.0 libGLESv1_CM.so )
( cd usr/lib ; rm -rf libxatracker.so.2 )
( cd usr/lib ; ln -sf libxatracker.so.2.3.0 libxatracker.so.2 )
( cd usr/lib ; rm -rf libXvMCnouveau.so )
( cd usr/lib ; ln -sf libXvMCnouveau.so.1.0.0 libXvMCnouveau.so )
( cd usr/lib ; rm -rf libXvMCr600.so.1.0 )
( cd usr/lib ; ln -sf libXvMCr600.so.1.0.0 libXvMCr600.so.1.0 )
( cd usr/lib ; rm -rf libglapi.so )
( cd usr/lib ; ln -sf libglapi.so.0.0.0 libglapi.so )
( cd usr/lib ; rm -rf libglapi.so.0 )
( cd usr/lib ; ln -sf libglapi.so.0.0.0 libglapi.so.0 )
( cd usr/lib ; rm -rf libEGL.so.1 )
( cd usr/lib ; ln -sf libEGL.so.1.0.0 libEGL.so.1 )
( cd usr/lib ; rm -rf libgbm.so )
( cd usr/lib ; ln -sf libgbm.so.1.0.0 libgbm.so )
( cd usr/lib/vdpau ; rm -rf libvdpau_radeonsi.so.1 )
( cd usr/lib/vdpau ; ln -sf libvdpau_radeonsi.so.1.0.0 libvdpau_radeonsi.so.1 )
( cd usr/lib/vdpau ; rm -rf libvdpau_r300.so.1.0 )
( cd usr/lib/vdpau ; ln -sf libvdpau_r300.so.1.0.0 libvdpau_r300.so.1.0 )
( cd usr/lib/vdpau ; rm -rf libvdpau_r300.so.1 )
( cd usr/lib/vdpau ; ln -sf libvdpau_r300.so.1.0.0 libvdpau_r300.so.1 )
( cd usr/lib/vdpau ; rm -rf libvdpau_r600.so.1 )
( cd usr/lib/vdpau ; ln -sf libvdpau_r600.so.1.0.0 libvdpau_r600.so.1 )
( cd usr/lib/vdpau ; rm -rf libvdpau_nouveau.so.1.0 )
( cd usr/lib/vdpau ; ln -sf libvdpau_nouveau.so.1.0.0 libvdpau_nouveau.so.1.0 )
( cd usr/lib/vdpau ; rm -rf libvdpau_nouveau.so )
( cd usr/lib/vdpau ; ln -sf libvdpau_nouveau.so.1.0.0 libvdpau_nouveau.so )
( cd usr/lib/vdpau ; rm -rf libvdpau_radeonsi.so.1.0 )
( cd usr/lib/vdpau ; ln -sf libvdpau_radeonsi.so.1.0.0 libvdpau_radeonsi.so.1.0 )
( cd usr/lib/vdpau ; rm -rf libvdpau_r600.so.1.0 )
( cd usr/lib/vdpau ; ln -sf libvdpau_r600.so.1.0.0 libvdpau_r600.so.1.0 )
( cd usr/lib/vdpau ; rm -rf libvdpau_r300.so )
( cd usr/lib/vdpau ; ln -sf libvdpau_r300.so.1.0.0 libvdpau_r300.so )
( cd usr/lib/vdpau ; rm -rf libvdpau_r600.so )
( cd usr/lib/vdpau ; ln -sf libvdpau_r600.so.1.0.0 libvdpau_r600.so )
( cd usr/lib/vdpau ; rm -rf libvdpau_nouveau.so.1 )
( cd usr/lib/vdpau ; ln -sf libvdpau_nouveau.so.1.0.0 libvdpau_nouveau.so.1 )
( cd usr/lib/vdpau ; rm -rf libvdpau_radeonsi.so )
( cd usr/lib/vdpau ; ln -sf libvdpau_radeonsi.so.1.0.0 libvdpau_radeonsi.so )
( cd usr/lib ; rm -rf libGLESv2.so )
( cd usr/lib ; ln -sf libGLESv2.so.2.0.0 libGLESv2.so )
( cd usr/lib ; rm -rf libOSMesa.so )
( cd usr/lib ; ln -sf libOSMesa.so.8.0.0 libOSMesa.so )
( cd usr/lib ; rm -rf libGLESv2.so.2 )
( cd usr/lib ; ln -sf libGLESv2.so.2.0.0 libGLESv2.so.2 )
( cd usr/lib ; rm -rf libGLESv1_CM.so.1 )
( cd usr/lib ; ln -sf libGLESv1_CM.so.1.1.0 libGLESv1_CM.so.1 )
( cd usr/lib ; rm -rf libXvMCr600.so )
( cd usr/lib ; ln -sf libXvMCr600.so.1.0.0 libXvMCr600.so )
